@@ -1,4 +1,4 @@
-from typing import Callable, Tuple, List, Union, Optional
+from typing import Callable, List, Optional, Tuple, Union
 
 import torch
 import torch.nn as nn
@@ -102,24 +102,22 @@ class LIGAttributions(Attributions):
     def word_attributions(self) -> list:
         wa = []
         if len(self.attributions_sum) >= 1:
-            for i, (word, attribution) in enumerate(
-                zip(self.tokens, self.attributions_sum)
-            ):
+            for i, (word, attribution) in enumerate(zip(self.tokens, self.attributions_sum)):
                 wa.append((word, float(attribution.cpu().data.numpy())))
             return wa
 
         else:
             raise AttributionsNotCalculatedError("Attributions are not yet calculated")
 
-    def summarize(self, end_idx=None):
-        self.attributions_sum = self._attributions.sum(dim=-1).squeeze(0)
-        self.attributions_sum = self.attributions_sum[:end_idx] / torch.norm(
-            self.attributions_sum[:end_idx]
-        )
+    def summarize(self, end_idx=None, flip_sign: bool = False):
+        if flip_sign:
+            multiplier = -1
+        else:
+            multiplier = 1
+        self.attributions_sum = self._attributions.sum(dim=-1).squeeze(0) * multiplier
+        self.attributions_sum = self.attributions_sum[:end_idx] / torch.norm(self.attributions_sum[:end_idx])
 
-    def visualize_attributions(
-        self, pred_prob, pred_class, true_class, attr_class, all_tokens
-    ):
+    def visualize_attributions(self, pred_prob, pred_class, true_class, attr_class, all_tokens):
 
         return viz.VisualizationDataRecord(
             self.attributions_sum,
